@@ -6,6 +6,9 @@ import traceback
 from dateutil.relativedelta import relativedelta
 import copy
 import os
+import random
+import string
+
 
 class envelope():
     def __init__(self,n,s,w,e):
@@ -120,14 +123,18 @@ class dataClass():
     scale_factor_ = np.float32(1.0)
     add_offset_ = np.float32(0.0)
 
-    def __init__(self,data, name, type_,coordinate, unit,missing_value=np.nan, scale_factor=np.float32(1.0), add_offset=np.float32(0.0),valid_range=[-999,999],long_name_=""):
+    def __init__(self,data, name, type_,coordinate, unit,missing_value=np.nan, scale_factor=np.float32(1.0), add_offset=np.float32(0.0),valid_range=[-999,9999],long_name_=""):
         self.data_, self.name_, self.type_, self.coordinate_, self.unit_ ,self.missing_value_ ,self.scale_factor_,self.add_offset_,self.valid_range_,self.long_name_= data, name,type_, coordinate, unit,missing_value, scale_factor, add_offset, valid_range, long_name_
 
     def print(self):
         print(self.data_, self.name_, self.type_, self.coordinate_, self.unit_,self.missing_value_,self.scale_factor_,self.add_offset_,self.valid_range_)
 		
 def mkNCCommonUni(output,dateTimeStart,dateTimeArr,isoArr,latArr,lonArr,dataClass4D=[],dataClass3D=[],dataClass2D=[],attributeDict={},format='NETCDF4'):
-    outputTmp = output+".tmp"
+    # 生成大小写字母的字符集
+    letters = string.ascii_letters
+    # 生成5位随机大小写字母的字符串
+    random_string = ''.join(random.choice(letters) for _ in range(5))
+    outputTmp = output+f".{random_string}"
     dataset = nc.Dataset(outputTmp,'w',format=format) #'NETCDF4_CLASSIC')
     
     try:
